@@ -294,9 +294,9 @@ def main():
             'type': 'dict',
             'v_range': [['6.4.0', '']],
             'options': {
-                'fortiportal': {'v_range': [['6.4.0', '7.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'fortiportal': {'v_range': [['6.4.0', '7.2.4'], ['7.4.0', '7.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'fortiwlm': {'v_range': [['6.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'sdwancontroller': {'v_range': [['6.4.0', '7.0.10']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'sdwancontroller': {'v_range': [['6.4.0', '7.0.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'status': {'v_range': [['6.4.0', '']], 'choices': ['disable', 'enable', 'qa', 'dev'], 'type': 'str'},
                 'cpu': {'v_range': [['6.4.5', '']], 'type': 'int'},
                 'default-address-pool_base': {'v_range': [['6.4.3', '']], 'type': 'str'},
@@ -325,9 +325,6 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
